package gs.log.v0.data

class LogMessageTests extends munit.FunSuite:

  import LogMessageTests.Syntax.*

  test("should instantiate a log message from a string literal") {
    val msg = log"1 2 3 4"
    assert(msg.str() == "1 2 3 4")
  }

  test("should support equality checks") {
    val msg = log"1 2 3 4"
    val alt = log"1 2 3 4"
    assert(msg == alt)
    assert(msg.str() == alt.str())
    assert(msg.toString() == "1 2 3 4")
    assert(msg.hashCode() == "1 2 3 4".hashCode())
  }

  test("should accept variables safe to log in clear text") {
    val x               = "foo".logClearText()
    val y               = 10.logClearText()
    val msg: LogMessage = log"x = $x, y = $y"
    val expected        = s"x = ${x.value.renderBytes()}, y = ${y.value.renderBytes()}"
    assert(msg.str() == expected)
  }

object LogMessageTests:

  private object Syntax extends LogMessage.Builder

end LogMessageTests
